==> certmanager-model-v1alpha2-6.4.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderWebhookFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderWebhookFluentImpl<A extends ACMEIssuerDNS01ProviderWebhookFluent<A>> extends BaseFluent<A> implements ACMEIssuerDNS01ProviderWebhookFluent<A>{
  public ACMEIssuerDNS01ProviderWebhookFluentImpl() {
  }
  public ACMEIssuerDNS01ProviderWebhookFluentImpl(ACMEIssuerDNS01ProviderWebhook instance) {
    this.withConfig(instance.getConfig()); 
    this.withGroupName(instance.getGroupName()); 
    this.withSolverName(instance.getSolverName()); 
  }
  private JsonNode config;
  private String groupName;
  private String solverName;
  public JsonNode getConfig() {
    return this.config;
  }
  public A withConfig(JsonNode config) {
    this.config=config; return (A) this;
  }
  public Boolean hasConfig() {
    return this.config != null;
  }
  public String getGroupName() {
    return this.groupName;
  }
  public A withGroupName(String groupName) {
    this.groupName=groupName; return (A) this;
  }
  public Boolean hasGroupName() {
    return this.groupName != null;
  }
  public String getSolverName() {
    return this.solverName;
  }
  public A withSolverName(String solverName) {
    this.solverName=solverName; return (A) this;
  }
  public Boolean hasSolverName() {
    return this.solverName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEIssuerDNS01ProviderWebhookFluentImpl that = (ACMEIssuerDNS01ProviderWebhookFluentImpl) o;
    if (config != null ? !config.equals(that.config) :that.config != null) return false;
    if (groupName != null ? !groupName.equals(that.groupName) :that.groupName != null) return false;
    if (solverName != null ? !solverName.equals(that.solverName) :that.solverName != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(config,  groupName,  solverName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (groupName != null) { sb.append("groupName:"); sb.append(groupName + ","); }
    if (solverName != null) { sb.append("solverName:"); sb.append(solverName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha2-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEIssuerDNS01ProviderWebhookFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderWebhookFluentImpl<A extends ACMEIssuerDNS01ProviderWebhookFluent<A>> extends BaseFluent<A> implements ACMEIssuerDNS01ProviderWebhookFluent<A>{
  public ACMEIssuerDNS01ProviderWebhookFluentImpl() {
  }
  public ACMEIssuerDNS01ProviderWebhookFluentImpl(ACMEIssuerDNS01ProviderWebhook instance) {
    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withGroupName(instance.getGroupName());
      this.withSolverName(instance.getSolverName());
    }
  }
  private JsonNode config;
  private String groupName;
  private String solverName;
  public JsonNode getConfig() {
    return this.config;
  }
  public A withConfig(JsonNode config) {
    this.config=config; return (A) this;
  }
  public Boolean hasConfig() {
    return this.config != null;
  }
  public String getGroupName() {
    return this.groupName;
  }
  public A withGroupName(String groupName) {
    this.groupName=groupName; return (A) this;
  }
  public Boolean hasGroupName() {
    return this.groupName != null;
  }
  public String getSolverName() {
    return this.solverName;
  }
  public A withSolverName(String solverName) {
    this.solverName=solverName; return (A) this;
  }
  public Boolean hasSolverName() {
    return this.solverName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderWebhookFluentImpl that = (ACMEIssuerDNS01ProviderWebhookFluentImpl) o;
    if (!java.util.Objects.equals(config, that.config)) return false;

    if (!java.util.Objects.equals(groupName, that.groupName)) return false;

    if (!java.util.Objects.equals(solverName, that.solverName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(config,  groupName,  solverName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (groupName != null) { sb.append("groupName:"); sb.append(groupName + ","); }
    if (solverName != null) { sb.append("solverName:"); sb.append(solverName); }
    sb.append("}");
    return sb.toString();
  }
  
}
